%define sname	xl2tpd

Summary:	Layer 2 Tunnelling Protocol Daemon (RFC 2661)
Name:		xl2tpd
Version:	1.3.18
Release:	%mkrel 1
License:	GPLv2
Url:		https://github.com/xelerance/xl2tpd
Group:		System/Base
Source0:	https://github.com/xelerance/xl2tpd/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	xl2tpd.service
Source2:	tmpfiles-xl2tpd.conf

#Patch1:	%%{sname}.c.patch
Patch2:		%{sname}-nokernel.patch

Requires:	ppp >= 2.4.5
# If you want to authenticate against a Microsoft PDC/Active Directory
# Requires: samba-winbind
BuildRequires:	libpcap-devel
BuildRequires:	systemd-units
BuildRequires:	pkgconfig(openssl)

Requires(post):		systemd
Requires(preun):	systemd
Requires(postun):	systemd

Conflicts:	xl2tpd-kernel
Provides:	l2tpd = %{version}
Provides:	xl2tpd-nokernel = %{version}

%description
xl2tpd is an implementation of the Layer 2 Tunnelling Protocol (RFC 2661).
L2TP allows you to tunnel PPP over UDP. Some ISPs use L2TP to tunnel user
sessions from dial-in servers (modem banks, ADSL DSLAMs) to back-end PPP
servers. Another important application is Virtual Private Networks where
the IPsec protocol is used to secure the L2TP connection (L2TP/IPsec,
RFC 3193). The L2TP/IPsec protocol is mainly used by Windows and 
Mac OS X clients. On Linux, xl2tpd can be used in combination with IPsec
implementations such as Openswan.
Example configuration files for such a setup are included in this RPM.

xl2tpd works by opening a pseudo-tty for communicating with pppd.
It runs completely in userspace.

xl2tpd supports IPsec SA Reference tracking to enable overlapping internal
NAT'ed IP's by different clients (e.g. all clients connecting from their
linksys internal IP 192.168.1.101) as well as multiple clients behind
the same NAT router.

xl2tpd supports the pppol2tp kernel mode operations on 2.6.23 or higher,
or via a patch in contrib for 2.4.x kernels.

Xl2tpd is based on the 0.69 L2TP by Jeff McAdams <jeffm@iglou.com>
It was de-facto maintained by Jacco de Leeuw <jacco2@dds.nl> in 2002 and 2003.

%prep
%autosetup -p1 -n %{sname}-%{version}

%build
export CFLAGS="$CFLAGS -fPIC -Wall"
export DFLAGS="%{optflags} -g -DDEBUG_PPPD -DDEBUG_CONTROL -DDEBUG_ENTROPY"
export LDFLAGS="$LDFLAGS -pie -Wl,-z,relro -Wl,-z,now"
%make_build

%install
%make_install PREFIX=%{_prefix}
install -d 0755 %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{sname}.service
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{sname}.conf

install -p -D -m644 examples/%{sname}.conf %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf
install -p -D -m644 examples/ppp-options.%{sname} %{buildroot}%{_sysconfdir}/ppp/options.%{sname}
install -p -D -m600 doc/l2tp-secrets.sample %{buildroot}%{_sysconfdir}/%{sname}/l2tp-secrets
install -p -D -m600 examples/chapsecrets.sample %{buildroot}%{_sysconfdir}/ppp/chap-secrets.sample
install -p -D -m755 -d %{buildroot}%{_rundir}/%{sname}

%post
%_tmpfilescreate %{sname}
%_post_service %{sname}

%preun
%_preun_service %{sname}

%files
%doc BUGS CHANGES CREDITS README.* TODO
%doc doc/README.patents examples/chapsecrets.sample
%license LICENSE
%{_sbindir}/%{sname}
%{_sbindir}/%{sname}-control
%{_bindir}/pfc
%{_mandir}/*/*
%dir %{_sysconfdir}/%{sname}
%config(noreplace) %{_sysconfdir}/%{sname}/*
%config(noreplace) %{_sysconfdir}/ppp/*
%ghost %dir %{_rundir}/%{sname}
%{_unitdir}/%{sname}.service
%config(noreplace) %{_tmpfilesdir}/%{sname}.conf
%ghost %attr(0600,root,root) %{_rundir}/%{sname}/l2tp-control


%changelog
* Thu Apr 25 2024 daviddavid <daviddavid> 1.3.18-1.mga10
+ Revision: 2060913
- new version: 1.3.18

* Sun Oct 23 2022 ghibo <ghibo> 1.3.17-1.mga9
+ Revision: 1898595
- Update to release 1.3.17

* Tue Mar 29 2022 umeabot <umeabot> 1.3.16-2.mga9
+ Revision: 1831159
- Mageia 9 Mass Rebuild

* Sat Dec 26 2020 daviddavid <daviddavid> 1.3.16-1.mga8
+ Revision: 1663937
- new version: 1.3.16

* Thu Feb 20 2020 umeabot <umeabot> 1.3.15-2.mga8
+ Revision: 1547360
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 1.3.15-1.mga8
+ Revision: 1487996
- new version: 1.3.15

* Fri Oct 11 2019 daviddavid <daviddavid> 1.3.14-1.mga8
+ Revision: 1451524
- new version: 1.3.14

* Sat Feb 16 2019 tmb <tmb> 1.3.6-7.mga7
+ Revision: 1367637
- use /run directly instead of /var/run

* Sun Sep 23 2018 umeabot <umeabot> 1.3.6-6.mga7
+ Revision: 1301921
- Mageia 7 Mass Rebuild

* Mon Feb 01 2016 umeabot <umeabot> 1.3.6-5.mga6
+ Revision: 930248
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.3.6-4.mga5
+ Revision: 748074
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.6-3.mga5
+ Revision: 690678
- Mageia 5 Mass Rebuild

* Sun Aug 17 2014 alexl <alexl> 1.3.6-2.mga5
+ Revision: 664719
- fixed unversioned provides
- used macroses for building (policy)

* Sat Apr 05 2014 alexl <alexl> 1.3.6-1.mga5
+ Revision: 611798
- add ghost for directory /var/run/xl2tpd
- imported package xl2tpd

